A crate containing clients to user nodes and the Lexe gateway.
Modules
- client
NodeClientandGatewayClient. This module contains the code for theNodeClientandGatewayClientthat the app uses to connect to the user node / gateway respectively, as well as related TLS configurations and certificates for both the client side (app) and server side (node/gateway).- credentials
- Client credentials. Client credentials for authentication with Lexe services.