NodeClient and GatewayClient.
This module contains the code for the NodeClient and GatewayClient
that the app uses to connect to the user node / gateway respectively, as
well as related TLS configurations and certificates for both the client side
(app) and server side (node/gateway).
Structs
- Gateway
Client - The client to the gateway itself, i.e. requests terminate at the gateway.
- Node
Client - The client to the user node.