NodeClient

Struct NodeClient 

pub struct NodeClient { /* private fields */ }
The client to the user node.

Requests are proxied via the gateway CONNECT proxies. These proxies avoid exposing user nodes to the public internet and enforce user authentication and other request rate limits.

  • Requests made to running nodes use the Run-specific RestClient.
  • Requests made to provisioning nodes use a RestClient which is created on-the-fly. This is because it is necessary to include a TLS config which checks the server’s remote attestation against a Measurement which is only known at provisioning time. This is also desirable because provision requests generally happen only once, so there is no need to maintain a connection pool after provisioning has complete.

Implementations

Source

impl NodeClient

pub fn new( rng: &mut impl Crng, use_sgx: bool, deploy_env: DeployEnv, gateway_client: GatewayClient, credentials: CredentialsRef<'_>, ) -> Result<Self>

pub fn user_pk(&self) -> Option<UserPk>

Returns the user’s public key, if available from the credentials.

Returns None if credentials were created before node v0.8.11, which didn’t include user_pk.

pub async fn create_client_credentials( &self, req: CreateRevocableClientRequest, ) -> Result<(RevocableClient, ClientCredentials)>

Ask the user node to create a new RevocableClient and return it along with its ClientCredentials.

pub async fn request_provision_token(&self) -> Result<BearerAuthToken>

Get a short-lived auth token with Scope::All for provisioning.